/**
 * Created by winber<winberxie@163.com>.
 * ComponentName Cell
 * Desc 组件描述内容
 * GroupName lm-component
 */
import React from 'react';
import PropTypes from 'prop-types';

import classNames from 'classnames';
import './index.scss';

export const CellsTitle = ({
                className,
                children,
                ...others
             }) => {

    const cls = classNames({
        'lm-cells-title': true,
    }, className);

    return (
        <div className={cls} {...others}>
            {children}
        </div>
    )

};

export const Cells = ({
                className,
                children,
                ...others
             }) => {

    const cls = classNames({
        'lm-cells': true,
    }, className);

    return (
        <div className={cls} {...others}>
            {children}
        </div>
    )

};

export const Label = ({
                className,
                children,
                ...others
             }) => {

    const cls = classNames({
        'lm-cell-label': true,
    }, className);

    return (
        <div className={cls} {...others}>
            {children}
        </div>
    )

};

export const Cell = ({
                className,
                children,
                component,
                href,
                ...others
             }) => {

    const cls = classNames({
        'lm-cells-item': true,
        'lm-cells-border': component || href,
    }, className);

    const renderDom = () => {
        if(component) {
            return (
                <component
                    className={cls}
                    {...others}
                >
                    {children}
                </component>
            )    
        } else if(href) {
            return (
                <a 
                    href={href}
                    className={cls}
                    {...others}
                >
                    {children}
                </a>
            )
            
        } else {
            return (
                <div className={cls} {...others}>
                    {children}
                </div>
            )
        }
    }





    return renderDom()
    
};

export const CellHeader = ({
                icon,
                className,
                children,
                ...others
             }) => {

    const cls = classNames({
        'lm-cells-item-header': true,
    }, className);

    return (
        <div className={cls} {...others}>
            <img alt="" src={icon}/>
        </div>
    )

};

export const CellBody = ({
                className,
                children,
                ...others
             }) => {

    const cls = classNames({
        'lm-cells-item-body': true,
    }, className);

    return (
        <div className={cls} {...others}>
            {children}
        </div>
    )

};
export const CellFooter = ({
                className,
                children,
                direction,
                ...others
             }) => {

    const cls = classNames({
        'lm-cells-item-footer': true,
        [`lm-cells-item-icon-${direction}`]:direction
    }, className);

    return (
        <div className={cls} {...others}>
            {children}
        </div>
    )
};

CellFooter.PropTypes = {
    direction: PropTypes.string
};